- X
an object of class FAMD [FactoMineR].
- axes
a numeric vector of length 2 specifying the dimensions to be
plotted.
- geom
a text specifying the geometry to be used for the graph. Allowed
values are the combination of c("point", "arrow", "text"). Use
"point" (to show only points); "text" to show only labels;
c("point", "text") or c("arrow", "text") to show arrows and
texts. Using c("arrow", "text") is sensible only for the graph of
variables.
- repel
logical; whether to use ggrepel to avoid overplotting text
labels. The old jitter argument is kept for backward
compatibility and is converted to repel = TRUE with a deprecation warning.
- habillage
an optional factor variable for coloring the observations by
groups. Default value is "none". If X is a FAMD object from FactoMineR
package, habillage can also specify the index of the factor variable in the
data.
- palette
the color palette to be used for coloring or filling by
groups. Allowed values include "grey" for grey color palettes; brewer
palettes e.g. "RdBu", "Blues", ...; or custom color palette e.g. c("blue",
"red"); and scientific journal palettes from ggsci R package, e.g.: "npg",
"aaas", "lancet", "jco", "ucscgb", "uchicago", "simpsons" and
"rickandmorty". Can be also a numeric vector of length(groups); in this
case a basic color palette is created using the function
palette.
- addEllipses
logical value. If TRUE, draws ellipses around the
individuals when habillage != "none".
- col.ind, col.var
color for individuals and variables, respectively. Can
be a continuous variable or a factor variable. Possible values also include
"cos2", "contrib", "coord", "x", and "y". In this case, the colors for
individuals/variables are automatically controlled by their qualities
("cos2"), contributions ("contrib"), coordinates (x^2 + y^2 , "coord"), x
values("x") or y values("y"). To use automatic coloring (by cos2, contrib,
....), make sure that habillage ="none".
- col.ind.sup
color for supplementary individuals
- alpha.ind, alpha.var
controls the transparency of individuals and
variables, respectively. The value can vary from 0 (total transparency)
to 1 (no transparency). Default value is 1. Possible values also include
"cos2", "contrib", "coord", "x" or "y". In this case, the transparency for
individual/variable colors are automatically controlled by their qualities
("cos2"), contributions ("contrib"), coordinates (x^2 + y^2 , "coord"), x
values("x") or y values("y"). To use this, make sure that habillage
="none".
- shape.ind, shape.var
point shapes of individuals, variables, groups and
axes
- col.quali.var
color for qualitative variables in fviz_famd_ind().
Default is "black".
- select.ind, select.var
a selection of individuals and variables to be
drawn. Allowed values are NULL or a list containing the arguments name,
cos2 or contrib:
name is a character vector containing
individuals/variables to be drawn
cos2 if cos2 is in [0, 1], ex: 0.6,
then individuals/variables with a cos2 > 0.6 are drawn. if cos2 > 1, ex: 5,
then the top 5 individuals/variables with the highest cos2 are drawn.
contrib if contrib > 1, ex: 5, then the top 5 individuals/variables with
the highest contributions are drawn
union: logical. When several of
name/cos2/contrib are given, FALSE (default) combines them with AND (each
condition further narrows the selection); TRUE combines them with OR (an
element is kept if it matches any condition), e.g. named items plus
the top-cos2 ones.
- gradient.cols
vector of colors to use for n-colour gradient. Allowed
values include brewer and ggsci color palettes.
- ...
Arguments to be passed to the function fviz()
- choice
The graph to plot in fviz_famd_var(). Allowed values include
one of c("var", "quanti.var", "quali.var", "quali.sup").
- col.var.sup
color for supplementary variables.