- x
an object of class dendrogram, hclust, agnes, diana, hcut,
hkmeans or HCPC (FactoMineR).
- k
the number of groups for cutting the tree.
- h
a numeric value. Cut the dendrogram by cutting at height h. (k
overrides h)
- k_colors, palette
a vector containing colors to be used for the groups.
It should contains k number of colors. Allowed values include also "grey"
for grey color palettes; brewer palettes e.g. "RdBu", "Blues", ...; and
scientific journal palettes from ggsci R package, e.g.: "npg", "aaas",
"lancet", "jco", "ucscgb", "uchicago", "simpsons" and "rickandmorty".
- show_labels
a logical value. If TRUE, leaf labels are shown. Default
value is TRUE.
- color_labels_by_k
logical value. If TRUE, labels are colored
automatically by group when k != NULL.
- label_cols
a vector containing the colors for labels.
- labels_track_height
a positive numeric value for adjusting the room for the
labels. Used only when type = "rectangle".
- repel
logical value. Use repel = TRUE to avoid label overplotting when
type = "phylogenic".
- lwd
a numeric value specifying branches and rectangle line width.
- type
type of plot. Allowed values are one of "rectangle", "triangle",
"circular", "phylogenic".
- phylo_layout
the layout to be used for phylogenic trees. Default value
is "layout.auto". Allowed values include:
layout.auto, layout_with_drl,
layout_as_tree, layout.gem,
layout.mds and layout_with_lgl.
- rect
logical value specifying whether to add a rectangle around
groups. Used only when k != NULL.
- rect_border, rect_lty
border color and line type for rectangles.
- rect_fill
a logical value. If TRUE, fill the rectangle.
- lower_rect
a value of how low should the lower part of the rectangle
around clusters. Ignored when rect = FALSE.
- horiz
a logical value. If TRUE, an horizontal dendrogram is drawn.
- cex
size of labels
- main, xlab, ylab
main and axis titles
- sub
Plot subtitle. If NULL, the method used hierarchical clustering is
shown. To remove the subtitle use sub = "".
- ggtheme
function, ggplot2 theme name. Default value is
theme_classic(). Allowed values include ggplot2 official themes:
theme_gray(), theme_bw(), theme_minimal(), theme_classic(), theme_void(),
....
- ...
other arguments to be passed to the function plot.dendrogram()