- x
numeric matrix or data frame. In the function fviz_nbclust(), x can
be the results of the function NbClust().
- FUNcluster
a partitioning function which accepts as first argument a
(data) matrix like x, second argument, say k, k >= 2, the number of
clusters desired, and returns a list with a component named cluster which
contains the grouping of observations. Allowed values include: kmeans,
cluster::pam, cluster::clara, cluster::fanny, hcut, etc. This argument is
not required when x is an output of the function
NbClust::NbClust().
- method
the method to be used for estimating the optimal number of
clusters. Possible values are "silhouette" (for average silhouette width),
"wss" (for total within sum of square) and "gap_stat" (for gap statistics).
- diss
dist object as produced by dist(), i.e.: diss = dist(x, method =
"euclidean"). Used to compute the average silhouette width of clusters, the
within sum of square and hierarchical clustering. If NULL, dist(x) is
computed with the default method = "euclidean"
- k.max
the maximum number of clusters to consider, must be at least two.
- nboot
integer, number of Monte Carlo ("bootstrap") samples. Used only for determining the number of clusters
using gap statistic.
- verbose
logical value. If TRUE, the result of progress is printed.
- barfill, barcolor
fill color and outline color for bars
- linecolor
color for lines
- print.summary
logical value. If true, the optimal number of clusters
are printed in fviz_nbclust().
- ...
optionally further arguments for FUNcluster()
- gap_stat
an object of class "clusGap" returned by the function
clusGap() [in cluster package]
- maxSE
a list containing the parameters (method and SE.factor) for
determining the location of the maximum of the gap statistic (Read the
documentation ?cluster::maxSE). Allowed values for maxSE$method include:
"globalmax": simply corresponds to the global maximum,
i.e., is which.max(gap)
"firstmax": gives the location of the first
local maximum
"Tibs2001SEmax": uses the criterion, Tibshirani et al
(2001) proposed: "the smallest k such that gap(k) >= gap(k+1) - s_k+1".
It's also possible to use "the smallest k such that gap(k) >= gap(k+1) -
SE.factor*s_k+1" where SE.factor is a numeric value which can be 1
(default), 2, 3, etc.
"firstSEmax": location of the first f() value
which is not larger than the first local maximum minus SE.factor * SE.f[],
i.e, within an "f S.E." range of that maximum.
see ?cluster::maxSE for more options