- x
a numeric matrix, numeric data frame or a dissimilarity matrix.
- k
a single integer specifying the number of clusters to be generated.
Must be at least 2 and smaller than the number of observations.
- isdiss
logical value specifying whether x is already a
dissimilarity matrix. If TRUE, x must inherit from class
"dist".
- hc_func
the hierarchical clustering function to be used. Default value is "hclust". Possible values
is one of "hclust", "agnes", "diana". Abbreviation is allowed.
- hc_method
the agglomeration method to be used (?hclust) for hclust() and agnes():
"ward.D", "ward.D2", "single", "complete", "average", ...
- hc_metric
character string specifying the metric to be used for calculating
dissimilarities between observations. Allowed values are those accepted by the function dist() [including "euclidean", "manhattan", "maximum",
"canberra", "binary", "minkowski"] and correlation based distance measures ["pearson", "spearman" or "kendall"].
- stand
logical value; default is FALSE. If TRUE, then the data will be standardized using the function scale().
Measurements are standardized for each variable (column), by subtracting the variable's mean value and
dividing by the variable's standard deviation.
- graph
logical value. If TRUE, the dendrogram is displayed.
- ...
not used.